from distutils.core import setup

setup(

    name = 'arjun_nester',
    version = '1.0.0',
    py_modules =['arjun_nester'],
    author = 'Arjun Prakash',
    author_email = 'arjuniyer.55@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A Simple printer of nested lists',
    )