
"""This module is defining a recursive function for printing out lists within lists"""

def print_lol(the_list):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item)
        else:
            print(each_item)
			
         
